/**
 * 导出 mixins、插件和组件，供外部使用
 *
 * 该文件用于整合项目中的全局混入（mixins）、插件（plugins）和组件（components），
 * 并通过 export 提供具名导出，同时提供一个默认导出对象，方便在 Vue 项目中统一引入。
 */

// 引入全局混入逻辑
import Mixins from "./mixins/index.js";

// 引入插件安装逻辑（如 Vue.use(...) 的封装）
import SetupPlugins from "./plugin/index.js";

// 引入自定义组件集合
import Components from "./components/index.js";

// 将混入和插件安装函数作为命名导出，便于按需使用
export const mixins = Mixins;
export const setupPlugins = SetupPlugins;
export const components = Components;

// 默认导出所有模块，可用于 Vue 应用的全局注册或配置
export default {
  mixins,
  components,
  setupPlugins,
};